┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/search/dolphinsearchbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/search/dolphinsearchbox.h')
-rw-r--r--src/search/dolphinsearchbox.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/search/dolphinsearchbox.h b/src/search/dolphinsearchbox.h
index ac5253d49..73e4936df 100644
--- a/src/search/dolphinsearchbox.h
+++ b/src/search/dolphinsearchbox.h
@@ -94,15 +94,16 @@ signals:
void searchTextChanged(const QString& text);
/**
* Is emitted if the search box gets the focus and
* requests the need for a UI that allows to adjust
* search options. It is up to the application to ignore
* this request.
*/
void requestSearchOptions();
private slots:
void emitSearchSignal();
+ void slotTextChanged(const QString& text);
private:
KLineEdit* m_searchInput;
@@ -94,15 +94,16 @@ signals:
void searchTextChanged(const QString& text);
/**
- * Is emitted if the search box gets the focus and
- * requests the need for a UI that allows to adjust
- * search options. It is up to the application to ignore
+ * Is emitted if the search box gets the focus or the text
+ * has been changed. It requests the need for an UI that allows to
+ * adjust search options. It is up to the application to ignore
* this request.
*/